@@ -1,14 +1,10 @@
 package AnyEvent::Filesys::Notify::Event;
 
-# ABSTRACT: Object to report changes in the monitored filesystem
-
-use Moo;
-use MooX::late;
-use namespace::sweep;
+use Moose;
 
 has path => ( is => 'ro', isa => 'Str', required => 1 );
 has type => ( is => 'ro', isa => 'Str', required => 1 );
-has is_dir => ( is => 'ro', isa => 'Bool', default => 0 );
+has is_dir => ( is => 'ro', isa => 'Str', default => 0 );
 
 sub is_created {
     return shift->type eq 'created';
@@ -22,18 +18,10 @@ sub is_deleted {
 
 1;
 
-__END__
-
-=pod
-
 =head1 NAME
 
 AnyEvent::Filesys::Notify::Event - Object to report changes in the monitored filesystem
 
-=head1 VERSION
-
-version 0.23_10
-
 =head1 SYNOPSIS
 
     use AnyEvent::Filesys::Notify;
@@ -59,7 +47,7 @@ Simple object to encapsulate information about the filesystem modifications.
 =head1 METHODS
 
 =head2 path()
-
+    
     my $modified_file = $event->path();
 
 Returns the path to the modified file.  This is the path as given by the user,
@@ -76,10 +64,10 @@ C<created>, C<modified>, or C<deleted>.
 
     my $is_dir  = $event->is_dir();
 
-Returns a true value if the path is a directory.
+Returns a true value is the path is a directory.
 
 =head2 is_created()
-
+    
     do_something($event) if $event->is_created;
 
 True if C<$event-E<gt>type eq 'created'>.
@@ -98,7 +86,7 @@ True if C<$event-E<gt>type eq 'deleted'>.
 
 =head1 SEE ALSO
 
-L<AnyEvent::Filesys::Notify>
+L<AnyEvent::Filesys::Notify::Event>
 
 =head1 BUGS
 
@@ -110,9 +98,10 @@ Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
+Copyright (C) 2009 by Mark Grimes
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.2 or,
+at your option, any later version of Perl 5 you may have available.
 
 =cut
